@@ -8,11 +8,21 @@ Created on Mon Sep 21 11:29:27 2020
 import pyvisa
 from time import sleep
 
+from serial.tools import list_ports
+
+
 class MaiTai:
 
-    def __init__(self):
+    def __init__(self,serial_number):
         rm = pyvisa.ResourceManager()
-        self.MaiTai = rm.open_resource('ASRL/dev/ttyUSB0::INSTR')
+        ports = list_ports.comports()
+        current_port = "None"
+        for port in ports:
+            if port.serial_number == serial_number:
+                current_port = port.name
+        if current_port == "None":
+            print("PORT NOT FOUND")
+        self.MaiTai = rm.open_resource(f'ASRL/{current_port}::INSTR')
         self.MaiTai.baud_rate = 115200
 
     def Shutter(self,val=0):
@@ -55,5 +65,4 @@ class MaiTai:
 
 if __name__=='__main__':
     MaiTai = MaiTai()
-    MaiTai.__init__()
 
