@@ -5,7 +5,7 @@ hwid = ["software"]
 
 
 class instrument:
-    def __init__(self):
+    def __init__(self,serial_number):
         pass
 
     def get_frame(self, exp_time):
